-module(rocket).

-behaviour(gen_server).

%% API
-export([start/2, left/0, right/0, down/0, pos/0, stop/0]).

%% gen_server callbacks
-export([init/1, handle_call/3, handle_cast/2, handle_info/2,
		 terminate/2, code_change/3]).

-define(SERVER, ?MODULE). 

-record(state, {x, y}).

%%%===================================================================
%%% API
%%%===================================================================

start(X, Y) ->
	gen_server:start({local, ?SERVER}, ?MODULE, [X, Y], []).

left()  -> gen_server:call(rocket, left),  rocket_panel:redraw().
right() -> gen_server:call(rocket, right), rocket_panel:redraw().
down()  -> gen_server:call(rocket, down),  rocket_panel:redraw().
pos()   -> gen_server:call(rocket, pos).
stop()  -> gen_server:call(rocket, stop).	

%%%===================================================================
%%% gen_server callbacks
%%%===================================================================

init([X, Y]) ->
	{ok, #state{x=X, y=Y}}.

handle_call(left, _From, #state{x=X, y=Y}) ->
	X1 = X-1,
	{reply, {X1, Y}, #state{x=X1, y=Y}};
handle_call(right, _From, #state{x=X, y=Y}) ->
	X1 = X+1,
	{reply, {X1, Y}, #state{x=X1, y=Y}};
handle_call(down, _From, #state{x=X, y=Y}) ->
	Y1 = Y-1,
	{reply, {X, Y1}, #state{x=X, y=Y1}};
handle_call(pos, _From, #state{x=X, y=Y}) ->
	{reply, {X, Y}, #state{x=X, y=Y}};
handle_call(stop, _From, State) ->
	{stop, normal, ok, State}.


handle_cast(_Msg, State) ->
	{noreply, State}.

handle_info(_Info, State) ->
	{noreply, State}.

terminate(_Reason, _State) ->
	ok.

code_change(_OldVsn, State, _Extra) ->
	{ok, State}.

%%%===================================================================
%%% Internal functions
%%%===================================================================
